@@ -30,7 +30,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 60935 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 63565 $")
 
 #include "asterisk/lock.h"
 #include "asterisk/file.h"
@@ -97,7 +97,7 @@ static void retrieve_file(char *dir)
 	void *fdm = MAP_FAILED;
 	SQLHSTMT stmt;
 	char sql[256];
-	char fmt[80]="";
+	char fmt[80]="", empty[10] = "";
 	char *c;
 	SQLLEN colsize;
 	char full_fn[256];
@@ -148,7 +148,7 @@ static void retrieve_file(char *dir)
 				break;
 			}
 
-			res = SQLGetData(stmt, 1, SQL_BINARY, NULL, 0, &colsize);
+			res = SQLGetData(stmt, 1, SQL_BINARY, empty, 0, &colsize);
 			fdlen = colsize;
 			if (fd > -1) {
 				char tmp[1]="";
