@@ -16,6 +16,9 @@
 #include "isdn_lib_intern.h"
 #include <mISDNuser/isdn_debug.h>
 
+
+int cfg_remember_l1=0;
+
 void misdn_join_conf(struct misdn_bchannel *bc, int conf_id);
 void misdn_split_conf(struct misdn_bchannel *bc, int conf_id);
 
@@ -1119,9 +1122,6 @@ int init_bc(struct misdn_stack *stack,  struct misdn_bchannel *bc, int midev, in
 		
 	}
 	
-	
-	
-	
 	{
 		stack_info_t *stinf;
 		ret = mISDN_get_stack_info(midev, stack->port, buff, sizeof(buff));
@@ -1318,7 +1318,7 @@ struct misdn_stack* stack_init( int midev, int port, int ptp )
 #endif
 		misdn_lib_get_short_status(stack);
 		misdn_lib_get_l1_up(stack);
-		misdn_lib_get_l2_up(stack);
+		misdn_lib_get_l2_up(stack); 
 	}
 
 	cb_log(8,0,"stack_init: port:%d lowerId:%x  upperId:%x\n",stack->port,stack->lower_id, stack->upper_id);
@@ -1711,7 +1711,7 @@ int misdn_lib_port_up(int port, int check)
 				if (stack->l1link && stack->l2link) {
 					return 1;
 				} else {
-					cb_log(0,port, "Port Down L2:%d L1:%d\n",
+					cb_log(1,port, "Port Down L2:%d L1:%d\n",
 						stack->l2link, stack->l1link);
 					return 0;
 				}
@@ -1719,7 +1719,7 @@ int misdn_lib_port_up(int port, int check)
 				if ( !check || stack->l1link )
 					return 1;
 				else {
-					cb_log(0,port, "Port down PMP\n");
+					cb_log(1,port, "Port down PMP\n");
 					return 0;
 				}
 			}
@@ -2848,8 +2848,11 @@ int handle_mgmt(msg_t *msg)
 			/*when the L2 goes UP, L1 needs to be UP too*/
 			stack->l1link=1;
 			stack->l2link=1;
-			if ( !stack->ptp && !stack->nt )
-				stack->l1link=2;
+			
+			if (cfg_remember_l1) {
+				if ( !stack->ptp && !stack->nt )
+					stack->l1link=2;
+			}
 			break;
 			
 		case SSTATUS_L2_RELEASED:
@@ -3183,13 +3186,15 @@ void misdn_lib_log_ies(struct misdn_bchannel *bc)
 void misdn_send_lock(struct misdn_bchannel *bc)
 {
 	//cb_log(0,bc->port,"Locking bc->pid:%d\n", bc->pid);
-	pthread_mutex_lock(&bc->send_lock->lock);
+	if (bc->send_lock)
+		pthread_mutex_lock(&bc->send_lock->lock);
 }
 
 void misdn_send_unlock(struct misdn_bchannel *bc)
 {
 	//cb_log(0,bc->port,"UnLocking bc->pid:%d\n", bc->pid);
-	pthread_mutex_unlock(&bc->send_lock->lock);
+	if (bc->send_lock)
+		pthread_mutex_unlock(&bc->send_lock->lock);
 }
 
 int misdn_lib_send_event(struct misdn_bchannel *bc, enum event_e event )
@@ -3628,7 +3633,7 @@ int misdn_lib_pid_restart(int pid)
 }
 
 /*Sends Restart message for every bchnanel*/
-int misdn_lib_send_restart(int port)
+int misdn_lib_send_restart(int port, int channel)
 {
 	struct misdn_stack *stack=find_stack_by_port(port);
 	cb_log(0, port, "Sending Restarts on this port.\n");
@@ -3639,9 +3644,17 @@ int misdn_lib_send_restart(int port)
 	dummybc.l3_id=MISDN_ID_GLOBAL;
 	dummybc.nt=stack->nt;
 
+	/*default is all channels*/
 	int max=stack->pri?30:2;
-	int i;
-	for (i=1;i<=max;i++) {
+	int i=1;
+	
+	/*if a channel is specified we restart only this one*/
+	if (channel > 0) {
+		i=channel;
+		max=channel;
+	}
+
+	for (;i<=max;i++) {
 		dummybc.channel=i;
 		cb_log(0, port, "Restarting channel %d\n",i);
 		misdn_lib_send_event(&dummybc, EVENT_RESTART);
