@@ -24,6 +24,10 @@
 ibuffer_t *astbuf;
 ibuffer_t *misdnbuf;
 
+struct send_lock {
+	pthread_mutex_t lock;
+};
+
 
 struct isdn_msg {
 	unsigned long misdn_msg;
