@@ -285,6 +285,10 @@ msg_t *build_setup (struct isdn_msg msgs[], struct misdn_bchannel *bc, int nt)
 			enc_ie_redir_nr(&setup->REDIR_NR, msg, 1, 1,  bc->pres, bc->screen, 0, bc->rad, nt,bc);
 	}
 
+	{
+		if (bc->keypad[0])
+			enc_ie_keypad(&setup->KEYPAD, msg, bc->keypad, nt,bc);
+	}
 	
   
 	if (*bc->display) {
@@ -325,7 +329,7 @@ msg_t *build_setup (struct isdn_msg msgs[], struct misdn_bchannel *bc, int nt)
 	}
 
 	if (bc->sending_complete) {
-		enc_ie_complete(&setup->BEARER,msg, bc->sending_complete, nt, bc);
+		enc_ie_complete(&setup->COMPLETE,msg, bc->sending_complete, nt, bc);
 	}
   
 #if DEBUG 
@@ -799,6 +803,7 @@ msg_t *build_restart (struct isdn_msg msgs[], struct misdn_bchannel *bc, int nt)
 	printf("Building RESTART Msg\n"); 
 #endif
 	enc_ie_channel_id(&restart->CHANNEL_ID, msg, 1,bc->channel, nt,bc);
+	enc_ie_restart_ind(&restart->RESTART_IND, msg, 0x80, nt, bc);
 
 	cb_log(0,bc->port, "Restarting channel %d\n", bc->channel);
 	
