@@ -28,7 +28,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 60398 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 62173 $")
 
 #include <fcntl.h>
 #include <stdlib.h>
@@ -837,7 +837,7 @@ static int find_transcoders(void)
 
 	info.op = ZT_TCOP_GETINFO;
 	if ((fd = open("/dev/zap/transcode", O_RDWR)) < 0) {
-		ast_log(LOG_NOTICE, "No Zaptel transcoder support!\n");
+		ast_log(LOG_DEBUG, "No Zaptel transcoder support!\n");
 		return 0;
 	}
 
