@@ -35,7 +35,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 44580 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 60660 $")
 
 #include "asterisk/frame.h"
 #include "asterisk/file.h"
@@ -427,10 +427,15 @@ static int ast_filehelper(const char *filename, const char *filename2, const cha
 										s->fmt = f;
 										s->trans = NULL;
 										s->filename = NULL;
-										if (s->fmt->format < AST_FORMAT_MAX_AUDIO)
+										if (s->fmt->format < AST_FORMAT_MAX_AUDIO) {
+											if (chan->stream)
+												ast_closestream(chan->stream);
 											chan->stream = s;
-										else
+										} else {
+											if (chan->vstream)
+												ast_closestream(chan->vstream);
 											chan->vstream = s;
+										}
 									} else {
 										fclose(bfile);
 										ast_log(LOG_WARNING, "Unable to open file on %s\n", fn);
