@@ -35,7 +35,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 51145 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 62547 $")
 
 #include "asterisk/lock.h"
 #include "asterisk/file.h"
@@ -734,7 +734,7 @@ static int builtin_atxfer(struct ast_channel *chan, struct ast_channel *peer, st
 				ast_set_flag(&(bconfig.features_caller), AST_FEATURE_DISCONNECT);
 				ast_set_flag(&(bconfig.features_callee), AST_FEATURE_DISCONNECT);
 				res = ast_bridge_call(transferer,newchan,&bconfig);
-				if (newchan->_softhangup || newchan->_state != AST_STATE_UP || !transferer->_softhangup) {
+				if (newchan->_softhangup || !transferer->_softhangup) {
 					ast_hangup(newchan);
 					if (f) {
 						ast_frfree(f);
